@@ -20,6 +20,7 @@
 #define KTP_ACTIONS_H
 
 #include <TelepathyQt/Types>
+#include <KUrl>
 
 #include <KTp/ktp-export.h>
 
@@ -32,6 +33,12 @@ namespace KTp {
 
 namespace Actions {
 
+    typedef QList<KUrl> DocumentList;
+
+    KTP_EXPORT Tp::PendingChannelRequest* startChat(const Tp::AccountPtr &account,
+                                                    const QString &contactIdentifier,
+                                                    bool delegateToPreferredHandler = true);
+
     KTP_EXPORT Tp::PendingChannelRequest* startChat(const Tp::AccountPtr &account,
                                                     const Tp::ContactPtr &contact,
                                                     bool delegateToPreferredHandler = true);
@@ -56,9 +63,22 @@ namespace Actions {
                                                        const Tp::ContactPtr &contact,
                                                        const QUrl &url);
 
+    KTP_EXPORT Tp::PendingChannelRequest* startCollaborativeEditing(const Tp::AccountPtr& account,
+                                                                    const Tp::ContactPtr& contact,
+                                                                    const DocumentList& documents,
+                                                                    bool needOpenEditor=false);
+
+
+    KTP_EXPORT Tp::PendingChannelRequest* startCollaborativeEditing(const Tp::AccountPtr& account,
+                                                                    const QString& chatroom,
+                                                                    const DocumentList& documents,
+                                                                    bool needOpenEditor=false);
+
     KTP_EXPORT void openLogViewer(const Tp::AccountPtr &account,
                                   const Tp::ContactPtr &contact);
 
+    KTP_EXPORT void openLogViewer(const QUrl &uri);
+
 
 } /* namespace Actions */
 
